summaryrefslogtreecommitdiff
path: root/src/or/directory.c
diff options
context:
space:
mode:
authorNick Mathewson <nickm@torproject.org>2008-12-18 16:11:24 +0000
committerNick Mathewson <nickm@torproject.org>2008-12-18 16:11:24 +0000
commit122170c1d3333185bacf361c523c8e19f0a5e8ba (patch)
tree89abcc91294222de3353c64d0e00f98618e9f55e /src/or/directory.c
parent6c6b0283cbc24f2d3d3bb7139e1cbeb5a35cfedd (diff)
downloadtor-122170c1d3333185bacf361c523c8e19f0a5e8ba.tar.gz
tor-122170c1d3333185bacf361c523c8e19f0a5e8ba.zip
Downlgrade tweak, and answer lots of XXX021s. No actual code fixes in this patch.
svn:r17686
Diffstat (limited to 'src/or/directory.c')
-rw-r--r--src/or/directory.c9
1 files changed, 7 insertions, 2 deletions
diff --git a/src/or/directory.c b/src/or/directory.c
index 13c3f71ab8..926d1843f8 100644
--- a/src/or/directory.c
+++ b/src/or/directory.c
@@ -540,7 +540,7 @@ directory_conn_is_self_reachability_test(dir_connection_t *conn)
routerinfo_t *me = router_get_my_routerinfo();
if (me &&
router_digest_is_me(conn->identity_digest) &&
- tor_addr_eq_ipv4h(&conn->_base.addr, me->addr) && /*XXXX021 prop 118*/
+ tor_addr_eq_ipv4h(&conn->_base.addr, me->addr) && /*XXXX prop 118*/
me->dir_port == conn->_base.port)
return 1;
}
@@ -1804,8 +1804,13 @@ connection_dir_client_reached_eof(dir_connection_t *conn)
int rejected = 0;
if (rejected_hdr) {
if (!strcmp(rejected_hdr, "Yes")) {
/* XXXX021 use this information; be sure to upload next one
* sooner. -NM */
+ /* XXXX021 On further thought, the task above implies that we're
+ * basing our regenerate-descriptor time on when we uploaded the
+ * last descriptor, not on the published time of the last
+ * descriptor. If those are different, that's a bad thing to
+ * do. -NM */
rejected = 1;
}
tor_free(rejected_hdr);
@@ -1804,8 +1804,13 @@ connection_dir_client_reached_eof(dir_connection_t *conn)
if (rejected_hdr) {
if (!strcmp(rejected_hdr, "Yes")) {
- /* XXXX021 use this information; be sure to upload next one
+ /* XXXX use this information; be sure to upload next one
* sooner. -NM */